@@ -28,16 +28,16 @@ __license__   = "LGPL"
 import pyatspi
 import re
 
-import braille
-import debug
-import eventsynthesizer
-import orca_state
-import settings
+from . import braille
+from . import debug
+from . import eventsynthesizer
+from . import orca_state
+from . import settings
 
-from braille_generator import BrailleGenerator
-from orca_i18n import _         # for gettext support
-from orca_i18n import C_        # to provide qualified translatable strings
-from orca_i18n import ngettext
+from .braille_generator import BrailleGenerator
+from .orca_i18n import _
+from .orca_i18n import C_
+from .orca_i18n import ngettext
 
 # [[[WDW - HACK Regular expression to split strings on whitespace
 # boundaries, which is what we'll use for word dividers instead of
@@ -156,7 +156,7 @@ class Word:
                 self.chars = None
             return self.chars
         elif attr.startswith('__') and attr.endswith('__'):
-            raise AttributeError, attr
+            raise AttributeError(attr)
         else:
             return self.__dict__[attr]
 
@@ -211,7 +211,7 @@ class Zone:
 
             return self.words
         elif attr.startswith('__') and attr.endswith('__'):
-            raise AttributeError, attr
+            raise AttributeError(attr)
         else:
             return self.__dict__[attr]
 
@@ -315,7 +315,7 @@ class TextZone(Zone):
             return self.words
 
         elif attr.startswith('__') and attr.endswith('__'):
-            raise AttributeError, attr
+            raise AttributeError(attr)
         else:
             return self.__dict__[attr]
 
@@ -525,7 +525,7 @@ class Line:
             elif attr == "height":
                 return bounds[3] - bounds[1]
         elif attr.startswith('__') and attr.endswith('__'):
-            raise AttributeError, attr
+            raise AttributeError(attr)
         else:
             return self.__dict__[attr]
 
@@ -640,8 +640,12 @@ class Context:
         currentWordIndex = 0
         currentCharIndex = 0
 
-        if orca_state.locusOfFocus and \
-           orca_state.locusOfFocus.getRole() == pyatspi.ROLE_TABLE_CELL:
+        try:
+            role = orca_state.locusOfFocus.getRole()
+        except:
+            role = None
+
+        if role == pyatspi.ROLE_TABLE_CELL:
             searchZone = orca_state.activeScript.\
                 utilities.realActiveDescendant(orca_state.locusOfFocus)
         else:
@@ -873,7 +877,7 @@ class Context:
         offset = 0
         lastEndOffset = -1
         upperMax = lowerMax = text.characterCount
-        upperMid = lowerMid = upperMax /2
+        upperMid = lowerMid = int(upperMax / 2)
         upperMin = lowerMin = 0
         upperY = lowerY = 0
         oldMid = 0
@@ -889,7 +893,7 @@ class Context:
                 upperMax = upperMid
             else:
                 upperMin = upperMid
-            upperMid = (upperMax - upperMin) /2 + upperMin
+            upperMid = int((upperMax - upperMin) / 2) + upperMin
 
         # performing binary search to locate last line inside clipped area
         oldMid = 0
@@ -904,7 +908,7 @@ class Context:
                 lowerMax = lowerMid
             else:
                 lowerMin = lowerMid
-            lowerMid = (lowerMax - lowerMin) /2 + lowerMin
+            lowerMid = int((lowerMax - lowerMin) / 2) + lowerMin
 
         # finding out the zones
         offset = upperMin
@@ -1429,54 +1433,54 @@ class Context:
         return lines
 
     def _dumpCurrentState(self):
-        print "line=%d, zone=%d, word=%d, char=%d" \
+        print("line=%d, zone=%d, word=%d, char=%d" \
               % (self.lineIndex,
                  self.zoneIndex,
                  self.wordIndex,
-                 self.zoneIndex)
+                 self.zoneIndex))
 
         zone = self.lines[self.lineIndex].zones[self.zoneIndex]
         text = zone.accessible.queryText()
 
         if not text:
-            print "  Not Accessibility_Text"
+            print("  Not Accessibility_Text")
             return
 
-        print "  getTextBeforeOffset: %d" % text.caretOffset
+        print("  getTextBeforeOffset: %d" % text.caretOffset)
         [string, startOffset, endOffset] = text.getTextBeforeOffset(
             text.caretOffset,
             pyatspi.TEXT_BOUNDARY_WORD_START)
-        print "    WORD_START: start=%d end=%d string='%s'" \
-              % (startOffset, endOffset, string)
+        print("    WORD_START: start=%d end=%d string='%s'" \
+              % (startOffset, endOffset, string))
         [string, startOffset, endOffset] = text.getTextBeforeOffset(
             text.caretOffset,
             pyatspi.TEXT_BOUNDARY_WORD_END)
-        print "    WORD_END:   start=%d end=%d string='%s'" \
-              % (startOffset, endOffset, string)
+        print("    WORD_END:   start=%d end=%d string='%s'" \
+              % (startOffset, endOffset, string))
 
-        print "  getTextAtOffset: %d" % text.caretOffset
+        print("  getTextAtOffset: %d" % text.caretOffset)
         [string, startOffset, endOffset] = text.getTextAtOffset(
             text.caretOffset,
             pyatspi.TEXT_BOUNDARY_WORD_START)
-        print "    WORD_START: start=%d end=%d string='%s'" \
-              % (startOffset, endOffset, string)
+        print("    WORD_START: start=%d end=%d string='%s'" \
+              % (startOffset, endOffset, string))
         [string, startOffset, endOffset] = text.getTextAtOffset(
             text.caretOffset,
             pyatspi.TEXT_BOUNDARY_WORD_END)
-        print "    WORD_END:   start=%d end=%d string='%s'" \
-              % (startOffset, endOffset, string)
+        print("    WORD_END:   start=%d end=%d string='%s'" \
+              % (startOffset, endOffset, string))
 
-        print "  getTextAfterOffset: %d" % text.caretOffset
+        print("  getTextAfterOffset: %d" % text.caretOffset)
         [string, startOffset, endOffset] = text.getTextAfterOffset(
             text.caretOffset,
             pyatspi.TEXT_BOUNDARY_WORD_START)
-        print "    WORD_START: start=%d end=%d string='%s'" \
-              % (startOffset, endOffset, string)
+        print("    WORD_START: start=%d end=%d string='%s'" \
+              % (startOffset, endOffset, string))
         [string, startOffset, endOffset] = text.getTextAfterOffset(
             text.caretOffset,
             pyatspi.TEXT_BOUNDARY_WORD_END)
-        print "    WORD_END:   start=%d end=%d string='%s'" \
-              % (startOffset, endOffset, string)
+        print("    WORD_END:   start=%d end=%d string='%s'" \
+              % (startOffset, endOffset, string))
 
     def setCurrent(self, lineIndex, zoneIndex, wordIndex, charIndex):
         """Sets the current character of interest.
