@@ -181,12 +181,16 @@ class Utilities(script_utilities.Utilities):
         index = obj.getIndexInParent() - 1
         if not (0 <= index < obj.parent.childCount - 1):
             obj = obj.parent
-            index = obj.childCount - 1
+            index = obj.getIndexInParent() - 1
 
         try:
             prevObj = obj.parent[index]
         except:
             prevObj = obj
+        else:
+            if prevObj.getRole() == pyatspi.ROLE_LIST and prevObj.childCount:
+                if self.isTextListItem(prevObj[0]):
+                    prevObj = prevObj[-1]
 
         return prevObj
 
@@ -208,5 +212,40 @@ class Utilities(script_utilities.Utilities):
             nextObj = obj.parent[index]
         except:
             nextObj = None
+        else:
+            if nextObj.getRole() == pyatspi.ROLE_LIST and nextObj.childCount:
+                if self.isTextListItem(nextObj[0]):
+                    nextObj = nextObj[0]
 
         return nextObj
+
+    def isTextListItem(self, obj):
+        """Returns True if obj is an item in a non-selectable list."""
+
+        if obj.getRole() != pyatspi.ROLE_LIST_ITEM:
+            return False
+
+        return not obj.parent.getState().contains(pyatspi.STATE_FOCUSABLE)
+
+    def isInlineContainer(self, obj):
+        """Returns True if obj is an inline/non-wrapped container."""
+
+        if obj.getRole() == pyatspi.ROLE_SECTION:
+            if obj.childCount > 1:
+                return self.onSameLine(obj[1], obj[1])
+
+            return False
+
+        if obj.getRole() == pyatspi.ROLE_LIST:
+            if obj.getState().contains(pyatspi.STATE_FOCUSABLE):
+                return False
+
+            if not obj.childCount:
+                return 'Text' in pyatspi.utils.listInterfaces(obj)
+
+            if obj.childCount == 1:
+                return False
+
+            return self.onSameLine(obj[0], obj[1])
+
+        return False
